==> zio-aws-cloudfront_2.12-7.31.10.1-sources.jar: zio/aws/cloudfront/model/Headers.scala <==
package zio.aws.cloudfront.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.cloudfront.model.primitives.Integer
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class Headers(
    quantity: Integer,
    items: Optional[Iterable[String]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudfront.model.Headers = {
    import Headers.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudfront.model.Headers
      .builder()
      .quantity(quantity: java.lang.Integer)
      .optionallyWith(
        items.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.items)
      .build()
  }
  def asReadOnly: zio.aws.cloudfront.model.Headers.ReadOnly =
    zio.aws.cloudfront.model.Headers.wrap(buildAwsValue())
}
object Headers {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudfront.model.Headers
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudfront.model.Headers =
      zio.aws.cloudfront.model.Headers(quantity, items.map(value => value))
    def quantity: Integer
    def items: Optional[List[String]]
    def getQuantity: ZIO[Any, Nothing, Integer] = ZIO.succeed(quantity)
    def getItems: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("items", items)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudfront.model.Headers
  ) extends zio.aws.cloudfront.model.Headers.ReadOnly {
    override val quantity: Integer = impl.quantity(): Integer
    override val items: Optional[List[String]] = zio.aws.core.internal
      .optionalFromNullable(impl.items())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudfront.model.Headers
  ): zio.aws.cloudfront.model.Headers.ReadOnly = new Wrapper(impl)
}

==> zio-aws-cloudfront_2.13-5.17.103.1-sources.jar: zio/aws/cloudfront/model/Headers.scala <==
package zio.aws.cloudfront.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.cloudfront.model.primitives.Integer
import scala.jdk.CollectionConverters._
final case class Headers(
    quantity: Integer,
    items: Option[Iterable[String]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudfront.model.Headers = {
    import Headers.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudfront.model.Headers
      .builder()
      .quantity(Integer.unwrap(quantity): java.lang.Integer)
      .optionallyWith(
        items.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.items)
      .build()
  }
  def asReadOnly: zio.aws.cloudfront.model.Headers.ReadOnly =
    zio.aws.cloudfront.model.Headers.wrap(buildAwsValue())
}
object Headers {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudfront.model.Headers
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudfront.model.Headers =
      zio.aws.cloudfront.model.Headers(quantity, items.map(value => value))
    def quantity: Integer
    def items: Option[List[String]]
    def getQuantity: ZIO[Any, Nothing, Integer] = ZIO.succeed(quantity)
    def getItems: ZIO[Any, AwsError, List[String]] =
      AwsError.unwrapOptionField("items", items)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudfront.model.Headers
  ) extends zio.aws.cloudfront.model.Headers.ReadOnly {
    override val quantity: Integer =
      zio.aws.cloudfront.model.primitives.Integer(impl.quantity())
    override val items: Option[List[String]] = scala
      .Option(impl.items())
      .map(value =>
        value.asScala.map { item =>
          item: String
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudfront.model.Headers
  ): zio.aws.cloudfront.model.Headers.ReadOnly = new Wrapper(impl)
}
